library(tidyverse) 
library(magick)

pixel_data_filename <- "pixel_data.csv"

template <- image_read("background_body.bmp") %>% 
  image_transparent(color="black", fuzz=50) 

system.time({
  for(i in 1:10) { # nrow(data)
    print(i)
    svg_filename <- paste("svg_files/", i, ".svg", sep="")
    bitmap <- image_read_svg(svg_filename) %>% 
      image_convert(format = "bmp") %>%
      image_convert(colorspace="gray") %>%
      image_threshold(type="black", threshold = "10%") %>%
      image_threshold(type="white", threshold = "90%") 
    overlay_image <- image_composite(bitmap, template, operator = "atop") %>%
      image_convert(colorspace="gray") %>%
      image_threshold(type="black", threshold = "10%") %>%
      image_threshold(type="white", threshold = "90%") 
    
    nPixels <- {{bitmap %>% image_data() %>% .[1,,]} != as.raw(255)} %>% sum()
    nPixels_outside <- {{overlay_image %>% image_data() %>% .[1,,]} != as.raw(255)} %>% sum()
    
    write.table(data.frame("id"= i, 
                           "nPix" = nPixels,
                           "nPixOut" = nPixels_outside), 
                pixel_data_filename,
                sep=";",
                row.names = FALSE,
                col.names = ifelse(i==1, TRUE, FALSE),
                append=TRUE)
  }
}) # end system.time